@@ -5,6 +5,7 @@ seqR <- function(
                  range,
                  from=1,
                  to=1,
+                 extend=0, # f-factor passed to extendrange
                  ...)
 {
 # only set from and to if range is given as input:
@@ -13,14 +14,12 @@ if(!missing(range))
   # Input checking:
   if(!is.vector(range)) stop("'range' must be a vector.")
   if(!is.numeric(range)) stop("'range' must be numeric.")
-  #
+  # accept long vectors:
+  if(length(range)>2) range <- base::range(range, na.rm=TRUE)
+  # actual work:
+  range <- extendrange(r=range, f=extend)
   from <- range[1]     # first
   to <- tail(range,1)  # and last value
-  if(length(range)>2)
-     {
-     from <- min(range, na.rm=TRUE) # min
-     to   <- max(range, na.rm=TRUE) # and max
-     }
   }
 # now call seq with from and to (obtained from range)
 seq(from=from, to=to, ...)
